Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(298)

Unified Diff: third_party/crashpad/crashpad/snapshot/mac/process_types.h

Issue 2236493004: Update Crashpad to 56b14bceefcec03fc11b3222c435522922f65640 (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Created 4 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: third_party/crashpad/crashpad/snapshot/mac/process_types.h
diff --git a/third_party/crashpad/crashpad/snapshot/mac/process_types.h b/third_party/crashpad/crashpad/snapshot/mac/process_types.h
index a1039dd00c7e746a919506e096b53f78476fed4b..664b37b674874d03d224d0c4fee9883af0e8ac72 100644
--- a/third_party/crashpad/crashpad/snapshot/mac/process_types.h
+++ b/third_party/crashpad/crashpad/snapshot/mac/process_types.h
@@ -29,10 +29,12 @@ namespace internal {
// Some structure definitions differ in 32-bit and 64-bit environments by having
// additional “reserved” padding fields present only in the 64-bit environment.
-// These Reserved64Only* types allow the process_types system to replicate these
-// structures more precisely.
-using Reserved64Only32 = char[0];
-using Reserved64Only64 = uint32_t;
+// These Reserved*_64Only* types allow the process_types system to replicate
+// these structures more precisely.
+using Reserved32_64Only32 = char[0];
+using Reserved32_64Only64 = uint32_t;
+using Reserved64_64Only32 = char[0];
+using Reserved64_64Only64 = uint64_t;
} // namespace internal
} // namespace process_types
@@ -61,7 +63,8 @@ DECLARE_PROCESS_TYPE_TRAITS_CLASS(Generic, 64)
using Pointer = internal::TraitsGeneric::Pointer; \
using IntPtr = internal::TraitsGeneric::IntPtr; \
using UIntPtr = internal::TraitsGeneric::UIntPtr; \
- using Reserved64Only = internal::TraitsGeneric::Reserved64Only; \
+ using Reserved32_64Only = internal::TraitsGeneric::Reserved32_64Only; \
+ using Reserved64_64Only = internal::TraitsGeneric::Reserved64_64Only; \
\
/* Initializes an object with data read from |process_reader| at \
* |address|, properly genericized. */ \
@@ -150,7 +153,8 @@ DECLARE_PROCESS_TYPE_TRAITS_CLASS(Generic, 64)
using Pointer = typename Traits::Pointer; \
using IntPtr = typename Traits::IntPtr; \
using UIntPtr = typename Traits::UIntPtr; \
- using Reserved64Only = typename Traits::Reserved64Only; \
+ using Reserved32_64Only = typename Traits::Reserved32_64Only; \
+ using Reserved64_64Only = typename Traits::Reserved64_64Only; \
\
/* Read(), ReadArrayInto(), and Size() are as in the generic user-visible \
* struct above. */ \

Powered by Google App Engine
This is Rietveld 408576698